@@ -19,9 +19,9 @@ class FastaRecord(object):
 
     @classmethod
     def is_current(klass, fasta_name):
-        utd = is_up_to_date(fasta_name + klass.ext, fasta_name) 
+        utd = is_up_to_date(fasta_name + klass.idx, fasta_name) 
         if not utd: return False
-        return is_up_to_date(fasta_name + klass.idx, fasta_name)
+        return is_up_to_date(fasta_name + klass.ext, fasta_name)
 
     def __init__(self, fh, start, stop):
 
@@ -33,25 +33,52 @@ class FastaRecord(object):
         return self.stop - self.start
 
     @classmethod
-    def prepare(klass, fasta_obj, seqinfo_generator):
+    def prepare(klass, fasta_obj, seqinfo_generator, flatten_inplace):
         """
         returns the __getitem__'able index. and the thing to get the seqs from.
         """
         f = fasta_obj.fasta_name
         if klass.is_current(f):
-            return cPickle.load(open(f + klass.idx)), \
-                               klass.modify_flat(f + klass.ext)
+            idx = cPickle.load(open(f + klass.idx))
+            if flatten_inplace: flat = klass.modify_flat(f)
+            else: flat = klass.modify_flat(f + klass.ext)
 
         idx = {}
         flatfh = open(f + klass.ext, 'wb')
-        for seqid, start, stop, seq in seqinfo_generator:
+        for i, (seqid, seq) in enumerate(seqinfo_generator):
+            if flatten_inplace:
+                if i == 0:
+                    flatfh.write('>%s\n' % seqid)
+                else:
+                    flatfh.write('\n>%s\n' % seqid)
+            start = flatfh.tell()
             flatfh.write(seq)
+            stop = flatfh.tell() 
             idx[seqid] = (start, stop)
             
         cPickle.dump(idx, open(f + klass.idx, 'wb'), -1)
         flatfh.close()
+        if flatten_inplace:
+            klass.copy_inplace(flatfh.name, f)
+            return idx, klass.modify_flat(f)
 
         return idx, klass.modify_flat(f + klass.ext)
+
+    @classmethod
+    def copy_inplace(klass, flat_name, fasta_name):
+        """
+        so they requested flatten_inplace, so we
+        overwrite the .fasta file with the .fasta.flat
+        file and save something in the .flat as a place-holder.
+        """
+        os.rename(flat_name, fasta_name)
+        # still need the flattend file to show
+        # it's current.
+        flatfh = open(fasta_name + klass.ext, 'wb')
+        flatfh.write('flattened')
+        flatfh.close()
+
+
     
     @classmethod
     def modify_flat(klass, flat_file):
@@ -59,12 +86,6 @@ class FastaRecord(object):
     
     def _adjust_slice(self, islice):
         l = len(self)
-        """
-        if not islice.start is None:
-            istart = self.stop + islice.start
-            while istart < 0:
-                istart += l
-        """
         if not islice.start is None and islice.start < 0:
             istart = self.stop + islice.start
         else:
@@ -185,11 +206,11 @@ class NpyFastaRecord(FastaRecord):
 
 class MemoryRecord(FastaRecord):
     @classmethod
-    def prepare(klass, fasta_obj, seqinfo_generator):
+    def prepare(klass, fasta_obj, seqinfo_generator, flatten_inplace=False):
         f = fasta_obj.fasta_name
         seqs = {}
         idx = {}
-        for seqid, start, stop, seq in seqinfo_generator:
+        for seqid, seq in seqinfo_generator:
             seqs[seqid] = (seq, None)
             
         return seqs, seqs
@@ -217,7 +238,7 @@ try:
         idx = ".tct"
 
         @classmethod
-        def prepare(klass, fasta_obj, seqinfo_generator):
+        def prepare(klass, fasta_obj, seqinfo_generator, flatten_inplace):
             f = fasta_obj.fasta_name
             if klass.is_current(f):
                 db = HDB()
@@ -226,12 +247,23 @@ try:
 
             db = HDB(f + klass.idx, tc.HDBOWRITER | tc.HDBOCREAT)
             flatfh = open(f + klass.ext, 'wb')
-            for seqid, start, stop, seq in seqinfo_generator:
+            for i, (seqid, seq) in enumerate(seqinfo_generator):
+                if flatten_inplace:
+                    if i == 0:
+                        flatfh.write('>%s\n' % seqid)
+                    else:
+                        flatfh.write('\n>%s\n' % seqid)
+                start = flatfh.tell()
                 flatfh.write(seq)
+                stop = flatfh.tell() 
                 db[seqid] = (start, stop)
 
             db.sync()
             flatfh.close()
+
+            if flatten_inplace:
+                klass.copy_inplace(flatfh.name, f)
+                return db, klass.modify_flat(f)
             return db, klass.modify_flat(f + klass.ext)
 
     __all__.append('TCRecord')
